get_cache_dir

Function get_cache_dir 

pub fn get_cache_dir() -> Result<PathBuf>
Returns the tool’s cache directory (~/.vct), creating it (and any missing parents) if it does not already exist.

Errors

Returns an error if the home directory cannot be determined or if the cache directory cannot be created.