get_pricing_cache_path

Function get_pricing_cache_path 

pub fn get_pricing_cache_path(date: &str) -> Result<PathBuf>
Returns the pricing cache file path for date.

The path is ~/.vct/model_pricing_<date>.json, where date is expected in YYYY-MM-DD form. As a side effect of resolving the cache directory, the directory is created if missing.

Errors

Returns an error if the cache directory cannot be resolved or created.