pub fn get_config_path() -> Result<PathBuf>Expand description
Returns the persistent settings file path (~/.vct/config.toml).
As a side effect of resolving the cache directory, the directory is created if missing.
Errors
Returns an error if the cache directory cannot be resolved or created.